/*
   errid.h -- PIKT error ids for all binaries

   $Header: /var/cvs/PIKT/pikt/src/lib/errid.h,v 1.16 2005/01/04 13:49:31 berto Exp $

   This file is part of PIKT ("Problem Informant/Killer Tool").
   Copyright (C) 1998,1999,2000,2001,2002,2003/2004,2005 by Robert Osterlund.

   PIKT is a trademark of the University of Chicago.  All Rights Reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   PIKT is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
   USA.

   Send problem reports, bouquets and brickbats to:  pikt-bugs@pikt.org
 */


/*
   this file is a continual work-in-progress; please send additions to,
   and corrections for, the error descriptions to:  pikt-bugs@pikt.org
 */


#define ERRID_DEBUG							0
/*
   Information useful for debugging, appearing sometimes on-screen and at
   other times in the log files; appears usually because
   --a program is run using the -G (debuG) option
   --in PIKT.conf, 'debug' is set to 'YES'
   --a program was compiled with, for example, DEEPDEBUG #define'd
   --in some cases, this might be the default
 */

#define ERRID_INFO							1
/*
   Information that may be of some interest, appearing sometimes on-screen
   but most often in the log files; appears usually because
   --in PIKT.conf, 'verbose_log' is set to 'YES'
   --in most cases, this is the default
 */


#define ERRID_CMD_PARSE_ERROR						1000
/*
   There is a syntax error in your command line.
   Perhaps you have
   --used an unknown option
   --specified an option using lower case (e.g., +h instead of +H)
   --used - instead of +, or vice versa
   --used conflicting options (e.g, 'piktc -it')
   --jumbled the order of command line elements
   --omitted a required command line element (e.g., +H ...)
   --specified an option but omitted its corresponding command line element
     (e.g., 'piktc -i' with no +A, +O, etc.)
   --incompletely specified command line elements (e.g., '+F' while omitting
     'all' or '<file1> <file2> ...')
   --misspecified a command string (e.g., omitted " or ')
   --made some other obscure mistake
   Please refer to
   --the on-line help, using the -h option, for a syntax summary
   --the Programs (piktc, piktc_svc, etc.) section of the Reference for
     further explanation
 */

#define ERRID_TAG_PARSE_ERROR						1001
/*
   There is a syntax error in your .cfg file, quite possibly in the
   #if-#endif layer.
   Perhaps you have
   --misspecified a comment (e.g., failed to close a forward-slash-star
     comment with a star-forward-slash)
   --misspelled a preprocessor directive (e.g., #include, #endif, #ifsys)
   --misspecified a file path or command string (e.g., omitted a " in an
     #include preprocessor directive, or a ] in an #exec directive)
   --used the wrong preprocessor directive (e.g., #if instead of #elif)
   --failed to specify host(s) after #if or #elif
   --specified host(s) after #endif
   --used && or || instead of & or | in your host specification(s)
   --omitted a ( or ) in your compound hosts specification(s)
   --made some other obscure mistake
   Please refer to
   --the Config Files section (also Format, Comments) of the Reference for
     further explanation
   --the Preprocessing (especially #if-#endif; #if, #ifdef Nesting; also
     #include; #indent; #verbatim; #exec; etc.) section(s) of the Reference
     for further explanation
   --the sample configurations (configs_samples) for working examples
   --the Preprocessing, Parse Errors section of the Reference, also
     configs_samples/macros.cfg for helpful hints and debugging techniques
 */

#define ERRID_DEF_PARSE_ERROR						1002
/*
   There is a syntax error in your .cfg file, quite possibly in the
   #ifdef-#endifdef layer.
   Perhaps you have
   --misspecified a comment (e.g., failed to close a forward-slash-star
     comment with a star-forward-slash)
   --misspelled a preprocessor directive (e.g., #include, #endifdef, #elsifdef)
   --misspecified a file path or command string (e.g., omitted a " in an
     #include preprocessor directive, or a ] in an #exec directive)
   --used the wrong preprocessor directive (e.g., #ifdef instead of #elifdef)
   --failed to specify a define identifier after #ifdef, #elifdef, #define,
     etc.
   --specified a define identifier after #endifdef
   --used forbidden characters in your define identifier(s) (permitted
     characters are:  letters, digits, -, _, .)
   --used && or || (or & or |) to make a compound define identifier (this is
     impermissible)
   --forgot to use = with #setdef
   --used an impermissible value with #setdef (permitted values are:
     true, TRUE, yes, YES, on, ON, and false, FALSE, no, NO, off, OFF)
   --made some other obscure mistake
   Please refer to
   --the Config Files section (also Format, Comments) of the Reference for
     further explanation
   --the Preprocessing (especially #ifdef-#endifdef, #define, #setdef;
     #if, #ifdef Nesting; also #include; #indent; #verbatim; #exec; etc.)
     section(s) of the Reference for further explanation
   --the sample configurations (configs_samples) for working examples
   --the Preprocessing, Parse Errors section of the Reference, also
     configs_samples/macros.cfg for helpful hints and debugging techniques
 */

#define ERRID_SYS_PARSE_ERROR						1003
/* 
   There is a syntax error in the systems.cfg file.
   Perhaps you have
   --misspecified a comment (e.g., failed to close a forward-slash-star
     comment with a star-forward-slash)
   --misspelled a preprocessor directive (e.g., #indent, #include) or keyword
     (e.g., hosts, members)
   --used an unrecognized preprocessor directive (e.g., #if, #ifdef, etc. are
     forbidden in systems.cfg)
   --used a PIKT macro (these are forbidden in systems.cfg)
   --misspecified a file path or command string (e.g., omitted a " in an
     #include preprocessor directive, or a ] in an #exec directive)
   --used forbidden characters in your stanza identifier(s) (permitted
     characters are:  letters, digits, -, _, .)
   --used forbidden characters in your hostnames (permitted characters are:
     letters, digits, -, _, .)
   --indented a stanza identifier (they should be flush left)
   --used reserved keywords (e.g., hosts, members) as hostnames
   --failed to follow a stanza identifier with one of the approved keywords:
     hosts, members, aliases
   --jumbled keyword order
   --make some other obscure mistake
   Please refer to
   --the Config Files, systems.cfg section (also Format, Comments) of the
     Reference for further explanation
   --the Preprocessing (especially #include; #indent; #verbatim; #exec; etc.)
     section(s) of the Reference for further explanation
   --the sample configurations (e.g., configs_samples/systems.cfg) for working
     examples
   --the Preprocessing, Parse Errors section of the Reference, also
     configs_samples/macros.cfg for helpful hints and debugging techniques
 */

#define ERRID_CFG_PARSE_ERROR						1004
/*
   There is a syntax error error in your .cfg file.
   Perhaps you have
   --misspecified a comment (e.g., failed to close a forward-slash-star
     comment with a star-forward-slash)
   --used forbidden characters in your stanza identifier(s) (permitted
     characters are:  letters, digits, -, _, .)
   --indented a stanza identifier (they should be flush left)
   --have an empty stanza (stanza identifier followed immediately by another
     stanza identifier)
   --failed to use keyword(s) appropriate to the .cfg file
   --misspelled keyword(s)
   --jumbled keyword order
   --omitted required keywords (e.g., if requires a corresponding endif, or fi)
   --omitted required keyword elements (e.g., in alarms.cfg, exec with no
     following command string)
   --provided an excess of keyword elements (e.g., in alerts.cfg give two
     mailcmd command strings)
   --used the wrong keywords (e.g., used 'status critical' instead of
     'status active')
   --failed to backslash-escape some .cfg file element (e.g., a parenthesis
     or quote within a command string
   --in alarms.cfg, jumbled or omitted script sections
   --in alarms.cfg, failed to begin each script line with an approved
     keyword (e.g., have the script line '#foo = 4' when it should be 'set
     #foo = 4)
   --misused a script element (e.g., used == instead of =, or vice versa)
   --misspecified a  string (e.g., omitted or mismatched ' and ")
   --misspecified a number (e.g., 47,500 when it should be 47500)
   --have unbalanced parentheses or brackets
   --used what appears to be a PIKT macro without properly backslash-escaping
     it
   --misspecified a script variable (must begin with $, #, @, or %)
   --tried to set a @ or % variable
   --tried to set a data input (e.g., set $inlin = "foo")
   --tried to set a function value (e.g., set #minute() = 30)
   --used && or || instead of & or |, or vice versa
   --used string keywords with numerical variables (e.g., '$foo != "bar"'
     instead of the correct '$foo ne "bar"'), or vice versa (e.g., '#foo eq 4'
     instead of the correct '#foo == 4')
   --used the wrong number of function arguments, or arguments of the wrong
     type
   --used a PIKT macro that when expanded, results in one of the above errors
   --#include'd a file (or #exec'ed a command) that results in one of the
     above errors
   --made some other obvious or obscure mistake (there are too many to
     completely categorize here)
   Please refer to
   --the appropriate section of Config Files in the Reference for further
     explanation
   --in the case of alarms.cfg, the Pikt Script Language section of the
     Reference for further explanation
   --the sample configurations (e.g., configs_samples/systems.cfg) for working
     examples
   --the Preprocessing, Parse Errors section of the Reference, also
     configs_samples/macros.cfg for helpful hints and debugging techniques
 */

#define ERRID_ALT_PARSE_ERROR						1005
/*
   There is a syntax error error in your Pikt script.
   Perhaps you have
   --used forbidden characters in your script identifier(s) (permitted
     characters are:  letters, digits, -, _, .)
   --indented a script identifier (they should be flush left)
   --have an empty script (script identifier followed immediately by another
     script identifier)
   --failed to use keyword(s) appropriate to a Pikt script
   --misspelled keyword(s)
   --jumbled keyword order
   --omitted required keywords (e.g., if requires a corresponding endif, or fi)
   --omitted required keyword elements (e.g., exec with no following command
     string)
   --provided an excess of keyword elements (e.g., exec followed by more than
     one command string)
   --used the wrong keywords (e.g., used 'status critical' instead of
     'status active')
   --failed to backslash-escape some .cfg file element (e.g., a parenthesis
     or quote within a command string
   --jumbled or omitted script sections
   --failed to begin each script line with an approved keyword (e.g., have
     the script line '#foo = 4' when it should be 'set #foo = 4')
   --misused a script element (e.g., used == instead of =, or vice versa)
   --misspecified a  string (e.g., omitted or mismatched ' and ")
   --misspecified a number (e.g., 47,500 when it should be 47500)
   --have unbalanced parentheses or brackets
   --used what appears to be a PIKT macro (macros appear in the .cfg files
     on the piktmaster, not on slaves)
   --misspecified a script variable (must begin with $, #, @, or %)
   --tried to set a @ or % variable
   --tried to set a data input (e.g., set $inlin = "foo")
   --tried to set a function value (e.g., set #minute() = 30)
   --used && or || instead of & or |, or vice versa
   --used string keywords with numerical variables (e.g., '$foo != "bar"'
     instead of the correct '$foo ne "bar"'), or vice versa (e.g., '#foo eq 4'
     instead of the correct '#foo == 4')
   --used the wrong number of function arguments, or arguments of the wrong
     type
   --made some other obvious or obscure mistake (there are too many to
     completely categorize here)
   Please refer to
   --the Pikt Script Language section of the Reference for further explanation
   --the sample configurations (e.g., configs_samples/systems.cfg) for working
     examples
 */

#define ERRID_EXPR_PARSE_ERROR						1006
/*
   There is a syntax error for an expression in your Pikt script.
   Perhaps you have
   --misspelled a function name
   --used an unknown operator
   --used ( or ) instead of [ or ], or vice versa
   --misused a script element (e.g., used == instead of =, or vice versa)
   --misspecified a  string (e.g., omitted or mismatched ' and ")
   --misspecified a number (e.g., 47,500 when it should be 47500)
   --have unbalanced parentheses or brackets
   --used && or || instead of & or |, or vice versa
   --used string keywords with numerical variables (e.g., '$foo != "bar"'
     instead of the correct '$foo ne "bar"'), or vice versa (e.g., '#foo eq 4'
     instead of the correct '#foo == 4')
   --used the wrong number of function arguments, or arguments of the wrong
     type
   --failed to separate function arguments properly using , (comma)
   --made some other obvious or obscure mistake (there are too many to
     completely categorize here)
   Please refer to
   --the Pikt Script Language section of the Reference for further explanation
   --the sample configurations (e.g., configs_samples/systems.cfg) for working
     examples
 */

#define ERRID_HST_PARSE_ERROR						1007
/*
   There is a syntax error in your .hst (history) file.
   Perhaps
   --you hand edited the history file and broke the syntax
   --the pikt binary has a debug that broke either the reading or writing
     of the history file
   Please
   --hand edit the history file (if you know what you are doing)
   --delete the history file, then rerun the script(s) to write a new history
     file
   --report a bug in the pikt binary (if indeed there is a relevant bug)
 */

#define ERRID_KEYS_PARSE_ERROR						1008
/*
   There is a syntax error in your keys.conf file.
   Perhaps you
   --misspecified a comment (e.g., used a forward-slash-star,
     star-forward-slash comment, which is not permitted; only // and #
     comments are permitted
   --used forbidden characters in your host identifier(s) (permitted
     characters are:  letters, digits, -, _, .)
   --misspecified a private_key string (e.g., omitted or mismatched ")
   --specified a private_key string having embedded spaces but without
     enclosing "
   --used " within a private_key
   --specified a uid or gid but not both
   --misspecified a uid or gid (e.g., 375,112,894 when it should be 375112894)
   --jumbled the key order (should be:  uid, gid, private_key)
   --made some other obvious or obscure mistake
   Please refer to
   --the keys.conf section of the Reference for further explanation
 */

#define ERRID_TIMING_PARSE_ERROR					1009
/*
   There is a syntax error in the timing specification(s) in your piktd.conf
   file.
   Perhaps you
   --misspecified a number
   --specified too few or too many timing parameters (should be the standard
     crontab five, and optionally a sixth drift parameter)
   --failed to follow the usual crontab syntax
   --used % with the drift parameter (should be a plain digit, i.e., the
     number of minutes of drift)
   --made some other obvious or obscure mistake
   Please refer to
   --the alerts.cfg section of the Reference for further explanation
   --the sample configurations (e.g., configs_samples/alerts.cfg) for working
     examples
 */

#define ERRID_CONF_PARSE_ERROR						1010
/*
   There is a syntax error in your PIKT.conf file.
   Perhaps you
   --misspecified a comment (e.g., used a forward-slash-star,
     star-forward-slash comment, which is not permitted; only // and #
     comments are permitted
   --misspelled a keyword (e.g., verbose_log) or parameter value (e.g., YES)
   --used an unrecognized keyword
   --misspecified a parameter string (e.g., omitted or mismatched ")
   --specified a parameter string having embedded spaces but without enclosing "
   --used a number where a string was appropriate, or vice versa
   --made some other obvious or obscure mistake
   Please refer to
   --the PIKT.conf section of the Reference for further explanation
   --the sample configurations (e.g., configs_samples/PIKT.conf) for working
     examples
*/


#define ERRID_HOST_UNKNOWN						1100
/*
   The referenced operating system, host, group, or alias is unknown (does
   not appear to be registered in your systems.cfg file).
   In some cases, this error generates a warning; in other cases, it is fatal.
   Please
   --change the reference (by fixing a misspelling maybe)
   --add the referenced identifier to your systems.cfg file
   --or perhaps ignore the error (in non-fatal cases)
   --refer to the systems.cfg section of the Reference for further explanation
*/

#define ERRID_DEFINE_UNKNOWN						1101
/*
   The referenced logical define is unknown (does not appear to be registered
   in your defines.cfg file).
   This is always a fatal error.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference (remove the #ifdef stanza)
   --or add the referenced logical define to your defines.cfg file
   --refer to the defines.cfg section of the Reference for further explanation
*/

#define ERRID_ALERT_UNKNOWN						1102
/*
   The referenced alert (Pikt script) is unknown (does not appear to be
   registered in your alerts.cfg file).
   This is always a fatal error.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference (remove from the command-line piktc +/-A, +/-S, list)
   --or add the referenced alert, or script, to your alerts.cfg file
   --refer to the alerts.cfg section of the Reference for further explanation
 */

#define ERRID_PROGRAM_UNKNOWN						1103
/*
   The referenced program is unknown (does not appear to be registered in your
   programs.cfg file).
   This is always a fatal error.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference (remove from the command-line piktc +/-P list)
   --or add the referenced program to your programs.cfg file
   --refer to the programs.cfg section of the Reference for further explanation
 */

#define ERRID_FILE_UNKNOWN						1104
/*
   The referenced file is unknown (does not appear to be registered in your
   files.cfg file).
   This is always a fatal error.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference (remove from the command-line piktc +/-F list)
   --or add the referenced file to your files.cfg file
   --refer to the files.cfg section of the Reference for further explanation
 */

#define ERRID_OBJECTSET_UNKNOWN						1105
/*
   The referenced object set is unknown (does not appear to be registered in
   your objects.cfg file).
   This is always a fatal error.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference (remove from the command-line piktc +/-O list)
   --or add the referenced object set to your objects.cfg file
   --refer to the files.cfg section of the Reference for further explanation
 */

#define ERRID_IDENT_UNKNOWN						1106
/*
   The referenced identifier is unknown (does not appear to be registered in
   the appropriate .cfg file).
   This is always a fatal error.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference
   --or add the referenced identifier to the appropriate .cfg file
   --refer to the Config Files section of the Reference for further explanation
 */

#define ERRID_ALARM_UNKNOWN						1107
/*
   When reading the .alt (alerts) file, pikt was unable to determine the
   current alarm script.
   This is always a fatal error.
   Please
   --inspect the .alt file, looking especially at the alarm script names
     (stanza identifiers, which should be flush left), to determine the cause
     of the problem
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_NAME_UNKNOWN						1108
/*
   The file or program referenced at the piktc command line is unknown.
   This is not necessarily a fatal error.
   Please
   --inspect the .cfg file(s), looking especially at the stanza identifiers,
     to determine why the referenced file or program is not detected
   --or remove the file or program from the piktc command line
   --refer to the piktc section of the Reference for further explanation
*/

#define ERRID_KEY_UNKNOWN						1109
/*
   The variable referenced in your script's keys statement is unrecognized.
   The current script will be bypassed.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference
   --or add the referenced variable to a preceding dat statement
   --refer to the Pikt Script Language and History Logging sections of the
     Reference for further explanation
 */

#define ERRID_VAR_UNKNOWN						1110
/*
   The referenced variable is unrecognized.
   Please
   --change the reference (by fixing a misspelling maybe)
   --remove the reference
   --or add the referenced variable to a preceding script statement
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_VAR_NAME_UNKNOWN						1111
/*
   When writing the .hst (history) file, pikt encountered an unknown variable.
   This is most likely an internal pikt bug and not due to any problem in
   your script.
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_FILE_CREATE_ERROR						1200
/*
   The system was unable to fulfill the attempted file creation request.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --the system has run out of free disk space or inodes
   --there are too many open files
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --the program called the system fopen() function specifying an improper mode
     (an unlikely internal program bug)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_FILE_OPEN_ERROR						1201
/*
   The system was unable to fulfill the attempted file open request.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the file referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --the system has run out of free disk space or inodes
   --there are too many open files
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --the program called the system fopen() function specifying an improper mode
     (an unlikely internal program bug)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct the
     error
 */

#define ERRID_FILE_CLOSE_ERROR						1202
/*
   The system was unable to fulfill the attempted file close request.
   Perhaps
   --the referenced file pointer is invalid
   --the associated file is too big
   --the system has run out of free disk space or inodes
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_FILE_STAT_ERROR						1203
/*
   The system was unable to fulfill the attempted file status request.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the file referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --the associated file is too big, or some other file attribute is
     unusually large
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
*/

#define ERRID_FILE_REMOVE_ERROR						1204
/*
   The system was unable to fulfill the attempted file remove request.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the file referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath involves too many symbolic links
   --this is a permissions problem
   --the file is in use and locked by another process
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_FILE_RENAME_ERROR						1205
/*
   The system was unable to fulfill the attempted file rename request.
   Perhaps
   --the directory or directories referenced in the file path(s) is (are)
     non-existent
   --the file referenced in the file path is non-existent
   --the filename(s) is (are) the empty string
   --the filepath(s) involve(s) too many symbolic links
   --the system has run out of free disk space or inodes
   --this is a permissions problem
   --the file(s) is (are) in use and locked by another process
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_FILE_READ_ERROR						1206
/*
   The system was unable to fulfill the attempted file read request.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the file referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --the file has not previously been opened for reading
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_FILE_WRITE_ERROR						1207
/*
   The system was unable to fulfill the attempted file write request.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the file referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --the system has run out of free disk space or inodes
   --the file has not previously been opened for writing
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_FILE_TELL_ERROR						1208
/*
   The system was unable to fulfill the attempted request to determine the
   current file position.
   Perhaps
   --the referenced file pointer is invalid
   --the file has not previously been opened
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
*/

#define ERRID_FILE_SEEK_ERROR						1209
/*
   The system was unable to fulfill the attempted request to adjust the
   current file position indicator.
   Perhaps
   --the referenced file pointer is invalid
   --the file has not previously been opened
   --there is an attempt to position beyond the end-of-file
   --the specified position is invalid (e.g., negative)
   --the system has run out of free disk space or inodes
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
*/

#define ERRID_FILE_NOT_FOUND						1210
/*
   The system was unable to find the specified file.
   Perhaps
   --the directory referenced in the file path is non-existent
   --the file referenced in the file path is non-existent
   --the filename is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_MKDIR_ERROR						1300
/*
   The system was unable to make the specified directory.
   Perhaps
   --the directory already exists
   --the parent directories referenced in the filepath are non-existent
   --the filepath is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --the system has run out of free disk space or inodes
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_CHMOD_ERROR						1400
/*
   The system was unable to change modes for the specified file or directory.
   Perhaps
   --the file mode is invalid
   --the referenced filepath is nonexistent
   --the filepath is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_CHOWN_ERROR						1401
/*
   The system was unable to change ownership of the specified file or
   directory.
   Perhaps
   --the owner is invalid
   --the referenced filepath is nonexistent
   --the filepath is the empty string
   --the filepath is too long
   --the filepath involves too many symbolic links
   --this is a permissions problem
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_FILE_NOT_OPEN_ERROR					1500
/*
   The specified file was not previously opened.
   Perhaps
   --the appropriate file or process open operation was never done
   --this is an internal pikt bug and not due to any problem in your script
     (unlikely)
   Please
   --call the #fopen() or #popen() functions before attempting a #read() or
     #write()
 */


#define ERRID_FILE_COPY_ERROR						1600
/*
   When attempting to do an automatic file backup, using the -b option,
   piktc encountered an unspecified error.
   Perhaps
   --the system has run out of free disk space or inodes
   --there are too many open files
   --this is a permissions problem
   --the target file checksum doesn't match the source file checksum
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_FILE_CHECKSUM_ERROR					1700
/*
   When attempting to checksum a file, piktc_svc encountered an error.
   Perhaps
   --the specified checksum is invalid
   --the specified file is nonexistent
   --there is a failure of one of the system file operations (open, read,
     close, etc.)
   --there is a problem with the file system or physical disk device
   --there is a network failure when connecting to a remote shared disk
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
*/


#define ERRID_FORK_ERROR						1800
/*
   The system was unable to fork a new process.
   Perhaps
   --the process limit has been reached
   --virtual memory has been exhausted
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_KILL_ERROR						1801
/*
   The system was unable to kill a process.
   Perhaps
   --the process doesn't exist or was dead already
   --this is an internal program bug (unlikely)
*/

#define ERRID_PIPE_ERROR						1802
/*
   The system was unable to open an I/O pipe.
   Perhaps
   --the process open file descriptor maximum has been reached
   --a file table entry could not be allocated
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_PIPE_WRITE_ERROR						1803
/*
   The system was unable to fulfill the attempted pipe write request.
   Perhaps
   --the referenced pipe is non-existent
   --the referenced pipe has not previously been opened for writing
   --this is due to some other unusual error
 */


#define ERRID_PROC_OPEN_ERROR						1900
/*
   The system was unable to fulfill the attempted process open request.
   Perhaps
   --the process limit has been reached
   --virtual memory has been exhausted
   --the process open file descriptor maximum has been reached
   --a file table entry could not be allocated
   --the program called the system popen() function specifying an improper
     mode (an unlikely internal program bug)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_PROC_CLOSE_ERROR						1901
/*
   The system was unable to fulfill the attempted process close request.
   Perhaps
   --the status of the child process could not be obtained
   --the process was already closed
*/


#define ERRID_MULTIPLE_PROCS						2000
/*
   The program was unable to determine a unique process id or parent process
   id for the specified process.
   Perhaps
   --there were two or more running processes by that name
   --the program was somehow unable to read the process table correctly
 */

#define ERRID_PROC_NOT_RUNNING						2001
/*
   The program was unable to determine the process id or parent process
   id for the specified process.
   Perhaps
   --the process was not running
   --the program was somehow unable to read the process table correctly
 */


#define ERRID_SYSTEM_ERROR						2100
/*
   pikt was unable to complete the requested #system() call.
   Perhaps
   --there was an error in the specified command string
   --the system was unable to fulfill the attempted process open request,
     because
     --the process limit has been reached
     --virtual memory has been exhausted
     --the process open file descriptor maximum has been reached
     --a file table entry could not be allocated
     --the program called the system popen() function specifying an improper
       mode (an unlikely internal program bug)
     --this is due to some other unusual error
   --the system was unable to fulfill the attempted process close request,
     because
     --the status of the child process could not be obtained
     --the process was already closed
   --this is due to some other unusual error (perhaps specific to the
     operating system)
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_COMMAND_ERROR						2101
/*
   pikt was unable to complete the requested $command() call.
   Perhaps
   --there was an error in the specified command string
   --the system was unable to fulfill the attempted process open request,
     because
     --the process limit has been reached
     --virtual memory has been exhausted
     --the process open file descriptor maximum has been reached
     --a file table entry could not be allocated
     --the program called the system popen() function specifying an improper
       mode (an unlikely internal program bug)
     --this is due to some other unusual error
   --the system was unable to fulfill the attempted process close request,
     because
     --the status of the child process could not be obtained
     --the process was already closed
   --this is due to some other unusual error (perhaps specific to the
     operating system)
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_SIGACTION_ERROR						2200
/*
   A call to the system sigaction() function failed.
   Perhaps
   --the function was passed an invalid signal number (an internal program bug)
   --this is due to some other unusual error
 */


#define ERRID_GETRLIMIT_ERROR						2300
/*
   A call to the system getrlimit() function failed.
   Perhaps
   --an invalid system resource was specified
   --this is an internal program bug (unlikely)
 */


#define ERRID_IPC_SIGNAL_INVALID					2400
/*
   In a PIKT IPC (interprocess communication) function, an invalid signal
   was detected.
   Perhaps
   --there is a problem with the system IPC
   --this is an internal program bug (unlikely)
 */


#define ERRID_MEMORY_ALLOCATION_FAILURE					2500
/*
   The system was unable to allocate memory for the requested task, due to
   a failed malloc(), calloc(), or strdup() function call.
   Perhaps
   --the size of the requested memory block exceeded system limits
   --sufficient free memory was (temporarily) unavailable
   --this is an internal program bug (unlikely)
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_FGETS_ERROR						2600
/*
   There was a failed system fgets() function call.
   Perhaps
   --there was a reference to an invalid file pointer (an internal program bug)
   --there was an attempt to read beyond the end of file
 */


#define ERRID_CLNT_CREATE_ERROR						2700
/*
   There was failed system clnt_create() function call.
   Perhaps
   --there was some unspecified network error
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error (perhaps specific to the
     operating system)
   Please
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_CLNT_CONTROL_ERROR					2800
/*
   There was failed system clnt_control() function call.
   Perhaps
   --there was some unspecified network error
   --this is an internal program bug (unlikely)
   --this is due to some other unusual error (perhaps specific to the
     operating system)
 */


#define ERRID_MULTIPLE_PIKTC						2900
/*
   The program detected signs of one or more running piktc processes.
   Perhaps
   --a piktc.lock file was detected (and there might in fact be no running
     piktc process, in which case the lock file is an orphan)
   --there was already one or more running piktc process(es)
   --the program was somehow unable to read the process table correctly
   Please
   --kill the blocking piktc process(es), if appropriate
   --remove the orphaned piktc.lock file, if appropriate
 */

#define ERRID_MULTIPLE_PIKTC_SVC					2901
/*
   The program detected signs of one or more running piktc_svc processes.
   Perhaps
   --a piktc_svc.lock file was detected (and there might in fact be no running
     piktc_svc process, in which case the lock file is an orphan)
   --there was already one or more running piktc_svc process(es)
   --the program was somehow unable to read the process table correctly
   Please
   --kill the blocking piktc_svc process(es), if appropriate
   --remove the orphaned piktc_svc.lock file, if appropriate
*/

#define ERRID_MULTIPLE_PIKT						2902
/*
   The program detected signs of one or more running pikt processes.
   Perhaps
   --a pikt alert lock file was detected (and there might in fact be no
     running pikt process, in which case the lock file is an orphan)
   --there was already one or more running pikt process(es)
   --the program was somehow unable to read the process table correctly
   Please
   --kill the blocking pikt process(es), if appropriate
   --remove the orphaned alert lock file, if appropriate
*/

#define ERRID_MULTIPLE_PIKTD						2903
/*
   The program detected signs of one or more running piktd processes.
   Perhaps
   --a piktd.lock file was detected (and there might in fact be no running
     piktd process, in which case the lock file is an orphan)
   --there was already one or more running piktd process(es)
   --the program was somehow unable to read the process table correctly
   Please
   --kill the blocking piktd process(es), if appropriate
   --remove the orphaned piktd.lock file, if appropriate
*/


#define ERRID_PIKTC_SVC_NOT_RUNNING					3000
/*
   The program was unable to find a running piktc_svc process on the remote
   system.
   Perhaps
   --there was no active piktc_svc process on the remote system
   --the remote system is down
   --there was some unspecified network error
   --there was a failed rpcinfo() function call (perhaps specific to the
     operating system)
   --there was some other unspecified RPC (Remote Process Call) error
   Please
   --(re)start piktc_svc on the remote system
   --if the error persists, take the appropriate system action to correct
     the error
 */


#define ERRID_PIKTD_NOT_RUNNING						3100
/*
   The program was unable to detect a running piktd
   Perhaps
   --the piktd process was not running
   --the program was somehow unable to read the process table correctly
   Please
   --start piktd (either manually or by using 'piktc -r' from the piktmaster)
 */


#define ERRID_SERVER_UNRESPONSIVE					3200
/*
   The master piktc was unable to communicate with the remote slave piktc_svc.
   Perhaps
   --there was no active piktc_svc process on the remote system
   --the remote system is down
   --there was some unspecified network error
   --there was some other unspecified RPC (Remote Process Call) error
   Please
   --start piktc_svc on the remote system
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_SERVICE_UNAUTHORIZED					3201
/*
   The requested service is not authorized on the remote slave system.
   Perhaps
   --the service has been deactivated in the remote system's PIKT.conf
   Please refer to
   --the piktmaster piktc.log and slave system's piktc_svc.log (perhaps
     running both piktc and piktc_svc with the -G, debug, option, and/or
     setting both system's PIKT.conf verbose_log parameter to TRUE)
   --the piktc, piktc_svc, and PIKT.conf sections of the Reference for
     further explanation
   --the source files piktc/rpcsvc.c and piktc/rpcclnt.c for further
     explanation
 */

#define ERRID_ACCESS_DENIED						3202
/*
   The piktc_svc on the remote slave system has denied your piktc service
   request.
   Perhaps
   --in the slave system's PIKT.conf, the master parameter doesn't match
     the actual piktmaster's fully qualified domain name
   --in the slave system's PIKT.conf, the master_address parameter doesn't
     match the actual piktmaster's ip address
   --in the slave system's PIKT.conf, the access parameter is set to 'local',
     but the piktmaster and slave don't share the same network domain
   --in the slave system's PIKT.conf, the uid parameter is set to a value
     that fails to match the uid of the calling piktmaster piktc, using
     the default uid, the piktmaster's PIKT.conf uid, or the remote system's
     uid as set in the piktmaster's keys.conf
   --in the slave system's PIKT.conf, the gid parameter is set to a value
     that fails to match the gid of the calling piktmaster piktc, using
     the default gid, the piktmaster's PIKT.conf gid, or the remote system's
     gid as set in the piktmaster's keys.conf
   --in the slave system's PIKT.conf, authenticate_by_master_ethernet_address
     is set to TRUE, and the piktmaster's ethernet (MAC) address fails to
     match the value of the master_ethernet_address parameter in the slave
     system's PIKT.conf
   --there has been a failure of secret key authentication:  in both system's
     (but especially the slave system's) PIKT.conf, auth_encryption_type is
     set to non-zero; but the secret key known to the piktmaster (whether
     the default, the piktmaster's private_key from its PIKT.conf or keys.conf,
     or the the slave's private_key from the piktmaster's keys.conf) fails
     to match the slave system's private_key (either the default, or the
     private_key from its PIKT.conf)
   --in the slave system's PIKT.conf, call_back is set to TRUE; but the
     slave system and service request are not currently registered in the
     piktmaster's piktc service queue, or the slave system's piktc_svc is
     for some reason unable to do a call_back to the piktmaster
   --this is an attempted illegitimate access
   Please refer to
   --the piktmaster piktc.log and slave system's piktc_svc.log (perhaps
     running both piktc and piktc_svc with the -G, debug, option, and/or
     setting both system's PIKT.conf verbose_log parameter to TRUE)
   --the piktc, piktc_svc, PIKT.conf, and keys.conf sections of the
     Reference for further explanation
   --the source files piktc/rpcsvc.c and piktc/rpcclnt.c for further
     explanation
 */


#define ERRID_SERVICE_REQUEST_UNAUTHENTICATED				3300
/*
   The piktc_svc on the local slave system has denied the master piktc service
   request.
   Perhaps
   --in the slave system's PIKT.conf, the master parameter doesn't match
     the actual piktmaster's fully qualified domain name
   --in the slave system's PIKT.conf, the master_address parameter doesn't
     match the actual piktmaster's ip address
   --in the slave system's PIKT.conf, the access parameter is set to 'local',
     but the piktmaster and slave don't share the same network domain
   --in the slave system's PIKT.conf, the uid parameter is set to a value
     that fails to match the uid of the calling piktmaster piktc, using
     the default uid, the piktmaster's PIKT.conf uid, or the remote system's
     uid as set in the piktmaster's keys.conf
   --in the slave system's PIKT.conf, the gid parameter is set to a value
     that fails to match the gid of the calling piktmaster piktc, using
     the default gid, the piktmaster's PIKT.conf gid, or the remote system's
     gid as set in the piktmaster's keys.conf
   --in the slave system's PIKT.conf, authenticate_by_master_ethernet_address
     is set to TRUE, and the piktmaster's ethernet (MAC) address fails to
     match the value of the master_ethernet_address parameter in the slave
     system's PIKT.conf
   --there has been a failure of secret key authentication:  in both system's
     (but especially the slave system's) PIKT.conf, auth_encryption_type is
     set to non-zero; but the secret key known to the piktmaster (whether
     the default, the piktmaster's private_key from its PIKT.conf or keys.conf,
     or the the slave's private_key from the piktmaster's keys.conf) fails
     to match the slave system's private_key (either the default, or the
     private_key from its PIKT.conf)
   --in the slave system's PIKT.conf, call_back is set to TRUE; but the
     slave system and service request are not currently registered in the
     piktmaster's piktc service queue, or the slave system's piktc_svc is
     for some reason unable to do a call_back to the piktmaster
   --this is an attempted illegitimate access
   Please refer to
   --the piktmaster piktc.log and slave system's piktc_svc.log (perhaps
     running both piktc and piktc_svc with the -G, debug, option, and/or
     setting both system's PIKT.conf verbose_log parameter to TRUE)
   --the piktc, piktc_svc, PIKT.conf, and keys.conf sections of the
     Reference for further explanation
   --the source files piktc/rpcsvc.c and piktc/rpcclnt.c for further
     explanation
 */

#define ERRID_MASTER_UNRESPONSIVE					3301
/*
   The local slave piktc_svc was unable to communicate with the remote
   master piktc_svc.
   Perhaps
   --the master system registered in the local slave PIKT.conf is not the
     actual piktmaster
   --there was no active piktc_svc process on the remote master system
   Please
   --check to ensure that the master setting in PIKT.conf matches on both
     the piktmaster and local slave systems
   --start piktc_svc on the remote system
   --if the error persists, take the appropriate system action to correct
     the error
 */

#define ERRID_SERVICE_REQUEST_NOT_REGISTERED_ON_MASTER			3302
/*
   The requested service and/or local slave system was not registered in
   the piktmaster's piktc service request queue.
   Perhaps
   --this is an attempted illegitimate access
   Please
   --compare the relevant piktc.log entries on the piktmaster with the
     relevant piktc_svc.log entries on the local slave system for insight
     into the problem
   --if the problem persists (and is not an attempted unauthorized break-in),
     run both the piktmaster piktc and the local slave system piktc_svc with
     the -G, debug, option, and/or set both system's PIKT.conf verbose_log
     parameter to TRUE, then compare relevant log entries again
 */


#define ERRID_RPCINFO_ERROR						3400
/*
   The piktmaster rpcinfo call to the remote slave system was unsuccessful.
   Perhaps
   --the remote system is down
   --the remote RPC server is down
   --the remote slave system is extremely busy
   --the network is extremely busy
   --there was some unspecified network error
   --there was some other unspecified RPC (Remote Process Call) error
   Please
   --in the piktmaster PIKT.conf, set the rpcinfo_retries parameter to a
     higher value (the default is 1)
   --(re)start the RPC server on the remote slave system
   --if the error persists, take the appropriate system or network action to
     correct the error
 */


#define ERRID_CWD_INDETERMINATE						3500
/*
   The system was unable to determine the current working directory.
   Perhaps
   --a parent directory cannot be read to get its name
   --the current working directory name is unusually long
   --there is a file system error
   Please
   --do a file system check (fsck) on the file system
   --if the current working directory is very deep within the file system,
     relocate to somewhere further up in the hierarchy
 */

#define ERRID_ENV_PATH_INDETERMINATE					3501
/*
   The system was unable to determine the path from the current working
   environment.
   Perhaps
   --the PATH environment variable has not been set, or has been set
     incorrectly
   Please
   --review the account shell initialization scripts, correcting the path
     setting if necessary
 */

#define ERRID_PIKT_HOMDIR_INDETERMINATE					3502
/*
   The program was unable to determine the PIKT home directory.
   Perhaps
   --the program was called with an improper program path
   --the PATH environment variable has not been set, or has been set
     incorrectly
   Please
   --call the program with a proper program path
   --review the account shell initialization scripts, correcting the path
     setting if necessary
   --set the appropriate homdir parameter in PIKT.conf, if necessary
 */


#define ERRID_FQDN_INDETERMINATE					3600
/*
   The system was unable to determine the fully qualified domain name of
   the current host.
   Perhaps
   --your network configuration is incorrect or incomplete
   --this is due to some other obscure problem
   Please
   --add the fully qualified domain name of this host to /etc/hosts (and
     possibly put it at the beginning of the name list)
   --review and fix your DNS configuration for this host
   --review and fix your NIS configuration for this host, if you use NIS
   --review and fix other possible problems in your network configuration
 */


#define ERRID_PIKT_MASTER_INDETERMINATE					3700
/*
   The program was unable to determine the piktmaster.
   Perhaps
   --the 'master' parameter is not set in PIKT.conf
   Please
   --set the 'master' parameter in PIKT.conf
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_PIKT_MASTER_ADDRESS_INDETERMINATE				3701
/*
   The program was unable to determine the piktmaster master_address.
   Perhaps
   --the master_address parameter is not set in PIKT.conf
   Please
   --set the master_address parameter in PIKT.conf
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_PIKT_MASTER_ETHERNET_ADDRESS_INDETERMINATE		3702
/*
   The program was unable to determine the piktmaster master_ethernet_address.
   Perhaps
   --the master_ethernet_address parameter is not set in PIKT.conf
   Please
   --set the master_ethernet_address parameter in PIKT.conf
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_PIKT_MASTER_AUTHENTICATE_INDETERMINATE			3703
/*
   The program was unable to determine the setting for either
   authenticate_by_master_address or authenticate_by_master_ethernet_address.
   Perhaps
   --one or both of these parameters is not set in PIKT.conf
   Please
   --set one or both of these parameters in PIKT.conf
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_DOMAIN_INDETERMINATE					3704
/*
   The program was unable to determine the setting for the 'domain' parameter.
   Perhaps
   --the 'domain' parameter is not set in PIKT.conf
   Please
   --set the 'domain' parameter in PIKT.conf
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_ACCESS_INDETERMINATE					3705
/*
   The program was unable to determine the setting for the 'access' parameter.
   Perhaps
   --the 'access' parameter is not set in PIKT.conf
   Please
   --set the 'access' parameter in PIKT.conf
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_PIKT_MASTER_NOT_FQDN					3706
/*
   The program did not detect a fully qualified domain name for the 'master'
   setting in PIKT.conf
   Perhaps
   --the 'master' parameter is a simple hostname (e.g., foo)
   Please
   --set the 'master' parameter to the piktmaster's fully qualified domain
     name (e.g., foo.bar.com)
   --refer to the PIKT.conf section of the Reference for further explanation
 */


#define ERRID_GETHOSTBYNAME_ERROR					3800
/*
   The program encountered an error when calling the system gethostbyname()
   function.
   Perhaps
   --the network naming system (DNS, NIS, ...) was down
   --your network configuration is incorrect or incomplete
   --the specified hostname is unusually long
   --this is due to some other obscure problem
   Please
   --add the fully qualified domain name of the specified host to /etc/hosts
     (and possibly put it at the beginning of the name list)
   --review and fix your DNS configuration for the specified host
   --review and fix your NIS configuration for the specified host, if you
     use NIS
   --review and fix other possible problems in your network configuration
 */

#define ERRID_REVERSE_DNS_LOOKUP_ERROR					3801
/*
   The program encountered an error when calling the system gethostbyaddr()
   function.
   Perhaps
   --the network naming system (DNS, NIS, ...) was down
   --your network configuration is incorrect or incomplete
   --this is due to some other obscure problem
   Please
   --add the fully qualified domain name of the specified host to /etc/hosts
     (and possibly put it at the beginning of the name list)
   --review and fix your DNS configuration for the specified host, in
     particular making sure that you have the appropriate reverse-lookup,
     address-to-hostname entry
   --review and fix your NIS configuration for the specified host, if you
     use NIS
   --review and fix other possible problems in your network configuration
 */


#define ERRID_DATA_ENCRYPTION_MISMATCH					3900
/*
   The program has detected a data_encryption_type mismatch in PIKT.conf
   between the piktmaster and slave system.
   Perhaps
   --the data_encryption_type parameter differs between the two systems
   Please
   --bring the value of the data_encryption_type parameter into agreement
     between the two systems
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_DATA_ENCRYPTION_TYPE_INVALID				3901
/*
   The program has detected an invalid data_encryption_type value in PIKT.conf.
   Perhaps
   --you have specified an invalid data_encryption_type value
   Please
   --specify a valid data_encryption_type value (a digit from 0 to the
     currently supported maximum)
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_AUTH_ENCRYPTION_TYPE_INVALID				3902
/*
   The program has detected an invalid auth_encryption_type value in PIKT.conf.
   Perhaps
   --you have specified an invalid auth_encryption_type value
   Please
   --specify a valid auth_encryption_type value (a digit from 0 to the
     currently supported maximum)
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_PVTKEY_LEN_MAX_EXCEEDED					3903
/*
   The program has detected an overly long private_key (or pvtkey) value
   in PIKT.conf or the separate private_key file.
   Perhaps
   --you have specified a private_key (or pvtkey) that is too long
   Please
   --specify a private_key (or pvtkey) of appropriate length
   --refer to the PIKT.conf section of the Reference for further explanation
 */

#define ERRID_PVTKEY_WEAK						3904
/*
   The program has detected a "weak" private_key (or pvtkey) in PIKT.conf.
   Perhaps
   --you have specified a private_key (or pvtkey) that is too short or not
     sufficiently random
   Please
   --specify a longer or more random private_key (or pvtkey)
   --refer to the rkey section section of the Reference (also the
     src/lib/crypt.c source file) for further explanation
 */

#define ERRID_KEYSUM_INDETERMINATE					3905
/*
   The program wasn't able to determine the internal variable keysum for
   this service request.
   Perhaps
   --there has been a failure of secret key authentication
   --this is an attempted illegitimate access
   --this is an internal program bug
   Please refer to
   --the piktmaster piktc.log and slave system's piktc_svc.log (perhaps
     running both piktc and piktc_svc with the -G, debug, option, and/or
     setting both system's PIKT.conf verbose_log parameter to TRUE)
   --the piktc, piktc_svc, PIKT.conf, and keys.conf sections of the
     Reference for further explanation
   --the source files piktc/rpcsvc.c and piktc/rpcclnt.c for further
     explanation
 */


#define ERRID_SERVICE_SETTING_INVALID					4000
/*
   The program detected an invalid service setting in PIKT.conf.
   Perhaps
   --you have specified an invalid setting
   Please
   --set the proper value (TRUE or FALSE) for this service
   --refer to the PIKT.conf section of the Reference for further explanation
 */


#define ERRID_TAB_BOUNDS_EXCEEDED					4100
/*
   The program has detected too-deep nesting of statement blocks while
   writing an alert (.alt) file.
   Perhaps
   --you are too deeply nesting your if, while, repeat, etc. structures
   Please
   --reduce the nesting level in your alarm script(s)
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */


#define ERRID_ALARM_NOT_REGISTERED					4200
/*
   The specified alarm is unrecognized.
   Perhaps
   --there is a syntax problem in your .cfg files
   --this is an internal program bug (unlikely)
   Please
   --review and as necessary fix your configuration
 */


#define ERRID_ALERT_NULL						4300
/*
   The program was unable to determine the alert name from the command line.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_FILE_PATH_MISMATCH					4400
/*
   The program has detected a mismatch between the file stanza identifier
   and the specified file path.
   Please
   --review the file stanza identifier and the specified file path and
     bring them into agreement
 */


#define ERRID_FILE_PATH_NOT_ABSOLUTE					4500
/*
   The specified file path is not absolute (i.e., does not begin with '/').
   Perhaps
   --in the path statement, the file path does not begin with '/', or it
     begins with a macro that resolves to a string that fails to begin
     with '/'
   --the program was unable to determine the PIKT homdir properly
   --you have misspecified the stgdir or difdir in PIKT.conf
   Please
   --in the path statement, begin the file path with '/', or fix the
     macro reference
   --review and, if necessary, fix the directory paths in PIKT.conf by
     making them absolute (i.e., begin them with '/')
 */

#define ERRID_FILE_PATH_NULL_STRING					4501
/*
   The specified file path is the null string.
   Perhaps
   --in the path statement, the file path is given as ""
   Please
   --in the path statement, specify a legitimate (absolute) file path
 */


#define ERRID_IDENT_ALREADY_REGISTERED					4600
/*
   The referenced identifier appeared earlier in the configuration, and you
   are specifying it again 
   Perhaps
   --you are specifying this identifier for the second (or third or ... ) time
   Please
   --ensure that each identifier is specified only once (per host)
   --refer to the Config Files section of the Reference for further
     explanation
 */

#define ERRID_IDENT_REGISTRATION_ERROR					4601
/*
   The referenced identifier could not be registered internally.
   Perhaps
   --the identifier was registered earlier
   Please
   --ensure that each identifier is specified only once (per host)
   --refer to the Config Files section of the Reference for further
     explanation
 */

#define ERRID_IDENT_MAX_LENGTH_EXCEEDED					4602
/*
   The stanza identifier is too long.
   Please
   --shorten the stanza identifier (to below the indicated MAXIDENT)
   --refer to the Config Files section of the Reference for further
     explanation
 */

#define ERRID_ALIAS_IDENT_NOT_HOST					4603
/*
   At attempt was made to register a host alias where the alias ident was not
   registered earlier as a host in systems.cfg.
   Perhaps
   --you are attempting to alias to a hostgroup, or another alias
   Please
   --make sure your alias definitions refer to a registered host
   --refer to the systems.cfg section of the Reference for further
     explanation
 */

#define ERRID_HASH_INVALID						4604
/*
   The program has computed an invalid ident hash.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_DATTYPE_INDETERMINATE					4700
/*
   The program was unable to determine the data type (whether # or $ or
   something else) for the specified variable.
   Please
   --review the Pikt script syntax, making sure that an appropriate # or $
     variable specification precedes any % or @ variable reference.
   --refer to the Pikt Script Language section of the Reference, especially
     the Objects, Names, and Datatypes subsection, for further explanation
 */

#define ERRID_DATTYPE_INVALID						4701
/*
   The program has detected an invalid variable data type.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_CFG_FILE_MISSING						4800
/*
   The indicated .cfg file was found to be missing.
   Perhaps
   --the file is truly missing
   --through a combination of #if, #ifdef and other preprocessor directives,
     the .cfg file is without effective content for the current host (less
     likely)
   Please (this may be a warning only and fixes may not truly be necessary)
   --provide the missing .cfg file
   --redo the #if, #ifdef, etc. directives to give effective content
 */

#define ERRID_CFG_NO_INPUT						4801
/*
   The indicated .cfg file was found, for the current host, to be without
   effective content.
   Perhaps
   --the file is truly missing
   --through a combination of #if, #ifdef and other preprocessor directives,
     the .cfg file is without effective content for the current host
   Please (this may be a warning only and fixes may not truly be necessary)
   --provide the missing .cfg file
   --redo the #if, #ifdef, etc. directives to give effective content
 */


#define ERRID_ARYNUM_MAX_EXCEEDED					4900
/*
   You have nested arrays too deeply.
   Perhaps
   --you are doing something like this:  #a[#b[#c[#d[...]]]]
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of array nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_ARYNUM_LESS_THAN_ZERO					4901
/*
   The internal program variable arynum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_IFNUM_MAX_EXCEEDED					5000
/*
   You have nested if ... endif too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of if ... endif nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_IFNUM_LESS_THAN_ZERO					5001
/*
   The internal program variable ifnum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_WHILENUM_MAX_EXCEEDED					5100
/*
   You have nested while ... endwhile too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of while ... endwhile nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_WHILENUM_LESS_THAN_ZERO					5101
/*
   The internal program variable whilenum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_REPEATNUM_MAX_EXCEEDED					5200
/*
   You have nested repeat ... until too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of repeat ... until nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_REPEATNUM_LESS_THAN_ZERO					5201
/*
   The internal program variable repeatnum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_FORNUM_MAX_EXCEEDED					5300
/*
   You have nested for ... endfor too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of for ... endfor nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_FORNUM_LESS_THAN_ZERO					5301
/*
   The internal program variable fornum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_SWITCHNUM_MAX_EXCEEDED					5400
/*
   You have nested switch ... endswitch too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of switch ... endswitch nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_SWITCHNUM_LESS_THAN_ZERO					5401
/*
   The internal program variable switchnum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_LOOPNUM_MAX_EXCEEDED					5500
/*
   You have nested a looping control structure too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of loop nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_LOOPNUM_LESS_THAN_ZERO					5501
/*
   The internal program variable loopnum was found to be less than zero.
   Perhaps
   --your script logic, and loop nesting, is overly complex
   --you have made a syntax error
   --this is an internal program bug
   Please
   --simplify your script, and loop nesting
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */   


#define ERRID_BREAK_WITHOUT_LOOP					5600
/*
   Your Pikt script has a break statement not inside a loop control structure
   (e.g., while ... endwhile).
   Perhaps
   --this is an actual instance of a stray, needless break statement
   --you have made some other syntax error
   --this is an internal program bug (unlikely)
   Please
   --review your script, removing the break statement if necessary
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_CONTINUE_WITHOUT_LOOP					5601
/*
   Your Pikt script has a continue statement not inside a loop control
   structure (e.g., while ... endwhile).
   Perhaps
   --this is an actual instance of a stray, needless continue statement
   --you have made some other syntax error
   --this is an internal program bug (unlikely)
   Please
   --review your script, removing the continue statement if necessary
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */


#define ERRID_IFDEFNUM_MAX_EXCEEDED					5700
/*
   You have nested #ifdef ... #endifdef too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of #ifdef ... #endifdef nesting
   --fix the syntax error
   --refer to the Preprocessing section of the Reference for further
     explanation
 */

#define ERRID_IFDEFNUM_LESS_THAN_ZERO					5701
/*
   The internal program variable ifnum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_IFHOSTNUM_MAX_EXCEEDED					5800
/*
   You have nested #if ... #endif too deeply.
   Perhaps
   --you truly are nesting too deeply
   --you have made some other syntax error
   Please
   --alter your config file to reduce the level of #if ... #endif nesting
   --fix the syntax error
   --refer to the Preprocessing section of the Reference for further
     explanation
 */

#define ERRID_IFHOSTNUM_LESS_THAN_ZERO					5801
/*
   The internal program variable ifnum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_IFFNNUM_MAX_EXCEEDED					5900
/*
   You have nested the #if() (or $if()) function too deeply.
   Perhaps
   --you are doing something like this:  #if(#if(#if(#if(...))))
   --you have made some other syntax error
   Please
   --alter your Pikt script to reduce the level of #if() (or $if()) function
     nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_IFFNNUM_LESS_THAN_ZERO					5901
/*
   The internal program variable ifnum was found to be less than zero.
   Perhaps
   --you have made a syntax error
   --this is an internal program bug
   Please
   --fix the syntax error
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_MACRO_UNKNOWN						6000
/*
   The referenced macro is unknown.
   Perhaps
   --you have misspelled the macro name
   Please
   --fix the macro name spelling
   --remove the macro reference
   --add the appropriate macro definition to macros.cfg
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_SELF_REFERENCING					6001
/*
   The referenced macro references itself.
   Perhaps
   --you are doing something like this:  =foo(=foo(=foo(...)))
   Please
   --remove the internal macro self-reference   
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_PARAMETERS_MAX_EXCEEDED				6002
/*
   The number of macro parameters exceeds the maximum.
   Please
   --reduce the number of macro parameters
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_PARAMETER_LEN_MAX_EXCEEDED				6003
/*
   The parametized macro parameter name is too long.
   Please
   --shorten the macro name
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_ARG_LEN_MAX_EXCEEDED				6004
/*
   The macro argument is too long.
   Please
   --shorten the macro argument
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_ARG_COUNT_MAX_EXCEEDED				6005
/*
   The number of macro arguments in the macro call exceeds the number of
   macro parameters in the macro definition.
   Please
   --reduce the number of arguments in the macro call
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_ARG_COUNT_TOO_SMALL					6006
/*
   The number of macro arguments in the macro call is less than the number of
   macro parameters in the macro definition.
   Please
   --increase the number of arguments in the macro call
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_PARAMETER_UNKNOWN					6007
/*
   The program was unable to locate the parametized macro parameter.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */

#define ERRID_MACRO_ARG_INVALID						6008
/*
   The referenced macro lacks an opening or closing parenthesis.
   Please
   --add the missing parenthesis
   --refer to the macros.cfg section of the Reference for further explanation
 */

#define ERRID_MACRO_EXPANSION_LEN_MAX_EXCEEDED				6009
/*
   When fully expanded, the referenced macro is too long
   Perhaps
   --the macro arguments are too long
   --the macro arguments are too many
   --the macros are too deeply nested (e.g., you are doing something like:
     =foo(=bar(=flim(=flam(...), ...), ...), ...))
   Please
   --shorten the macro arguments
   --reduce the number of macro arguments
   --reduce the macro argument nesting
   --refer to the macros.cfg section of the Reference for further explanation
 */


#define ERRID_INCTYPE_UNKNOWN						6100
/*
   The program has encountered an unknown include type.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */

#define ERRID_INCLUDE_FILE_UNSPECIFIED					6101
/*
   The program could not determine the include file.
   Perhaps
   --you failed to specify the include file, or specified the null string
   Please
   --specify a proper include file string
   --refer to the Preprocessing and #include sections of the Reference for
     further explanation
 */

#define ERRID_INCLUDE_FILE_CREATING_EMPTY				6102
/*
   The program did not find the referenced include file so is creating an
   empty one.
   Perhaps
   --you have misspelled the file (or directory) name
   Please
   --check the spelling of the specified include file
   --refer to the Preprocessing and #include sections of the Reference for
     further explanation
 */

#define ERRID_INCLUDE_FILE_MAX_EXCEEDED					6103
/*
   Your include files have nested too deeply.
   Perhaps
   --one include file includes another, which includes another, which
     includes another, ..., to a point beyond the supported nesting level
   Please
   --limit your include file nesting
   --refer to the Preprocessing and #include sections of the Reference for
     further explanation
 */

#define ERRID_INCNUM_LESS_THAN_ZERO					6104
/*
   The internal program variable incnum was found to be less than zero.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_DATA_POSITION_MAX_EXCEEDED				6200
/*
   The positional parameter in your data (dat) statement is too long.
   Please
   --shorten the positional parameter
   --refer to the Init Section section of the Reference for further
     explanation
 */

#define ERRID_DATA_POSITION_INVALID					6201
/*
   The positional parameter in your data (dat) statement is invalid.
   Perhaps
   --you have mismatched [ and ]
   --the end column is less than the begin column
   --a column specification is 0, or exceeds the allowed maximum
   --the field position is not an integer
   --the parameter is not one of the allowed types
   --in some other way does not conform to the allowed standards
   Please
   --specify the data position(s) properly
   --refer to the Init Section section of the Reference for further
     explanation
 */

#define ERRID_DATA_POSITION_INCONSISTENT				6202
/*
   The positional parameter in your data (dat) statement is inconsistent.
   Perhaps
   --in some way does not conform to the allowed standards
   --this is an internal program bug (unlikely)
   Please
   --specify the data position(s) properly
   --refer to the Init Section section of the Reference for further
     explanation
 */


#define ERRID_VAR_ALREADY_SPECIFIED					6300
/*
   The indicated variable was specified in a previous data (dat) statement.
   Please
   --remove the reference, or indicate a different variable name
   --refer to the Init Section section of the Reference for further
     explanation
 */

#define ERRID_VAR_NAME_RESERVED						6301
/*
   The indicated variable is one of the reserved variable names.
   Please
   --remove the reference, or indicate a different variable name
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_FN_NAME_RESERVED						6302
/*
   The indicated variable is one of the reserved function names.
   Please
   --remove the reference, or indicate a different variable name
   --refer to the Pikt Script Language and Functions sections of the
     Reference for further explanation
 */

#define ERRID_VAR_COUNT_MAX_EXCEEDED					6303
/*
   You have exceeded the maximum allowed number of variable names.
   Please
   --remove the reference, or indicate a different variable name
   --if you truly need so many variables, consider using a different
     scripting language with no such restriction (e.g., Perl or Python)
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_DATA_SLOT_ALREADY_TAKEN					6304
/*
   The internal data slot for this variable was already occupied.
   Perhaps
   --you are using, for example, both $foo and $foo[...] in the same script
   --this may be an internal program bug
   Please
   --fix the inconsistency
   --report the bug to pikt-bug@pikt.org
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_VAR_NAMES_INCONSISTENT					6305
/*
   The variable name is inconsistent with an earlier registration.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */

#define ERRID_VAL_TYPES_INCONSISTENT					6306
/*
   The variable's val type is inconsistent with an earlier registration.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */

#define ERRID_SCALAR_ARRAY_INCONSISTENT					6307
/*
   This variable's type is inconsistent with an earlier registration.
   Perhaps
   --you are using, for example, both $foo and $foo[...] in the same script
   Please
   --fix the inconsistency
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_DAT_TYPE_INCONSISTENT					6308
/*
   This variable's dat type is inconsistent with an earlier registration.
   Perhaps
   --you are using, for example, both $foo and #foo in dat statements
   Please
   --fix the inconsistency
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_ARRAY_TYPE_INCONSISTENT					6309
/*
   This variable's array type is inconsistent with an earlier registration.
   Perhaps
   --you are using, for example, both $foo[1] and $foo["bar"] in dat
     statements
   Please
   --fix the inconsistency
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_REFERENCE_IMPROPER				6310
/*
   The history variable reference was invalid.
   Perhaps
   --you are referencing, e.g., %inlin or %1
   --please fix variable type identifier, else remove the invalid reference
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_EXPRTYPE_INVALID						6311
/*
   The expression type was invalid.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
   
 */


#define ERRID_STATUS_LEVEL_TASK_MISSING					6400
/*
   Your script lacks status, level, and task statements.
   Please
   --add these missing statements
   --refer to the Pikt Script Language and Init Section sections of the
     Reference for further explanation
 */


#define ERRID_FOREACH_FUNCTION_INVALID					6500
/*
   The foreach statement in your Pikt script references in invalid function.
   Please
   --use any of the following after the foreach:  #split(), #parse(),
     #members(), #keys(), #skeys(), #sortkeys(), #rkeys(), #reversekeys()
   --refer to the Pikt Script Language and Objects, Names, Datatypes
     sections of the Reference for further explanation
 */


#define ERRID_NOT_NUMBER_FUNCTION					6600
/*
   The referenced apparent number function is in fact not one of the valid
   number functions.
   Perhaps
   --you are mistaking a string function (e.g., $checksum()) as a number
     function (e.g., mistakenly using #checksum())
   --you are doing something like '#foo(...),' where #foo() is not a valid
     function at all
   Please
   --fix the mistaken reference
   --refer to the Pikt Script Language and Functions sections of the
     Reference for further explanation
 */

#define ERRID_NOT_STRING_FUNCTION					6601
/*
   The referenced apparent string function is in fact not one of the valid
   string functions.
   Perhaps
   --you are mistaking a number function (e.g., #month()) as a string
     function (e.g., mistakenly using $month())
   --you are doing something like '$foo(...),' where $foo() is not a valid
     function at all
   Please
   --fix the mistaken reference
   --refer to the Pikt Script Language and Functions sections of the
     Reference for further explanation
 */


#define ERRID_FILE_STAT_TYPE_INVALID					6700
/*
   The internal filestat() function was passed an invalid file type.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_FDOPEN_ERROR						6800
/*
   The system was unable to fulfill the attempted file descriptor open
   request.
   Perhaps
   --there are too many open files
   --the system is short of memory
   --the program called the system fopen() function specifying an improper mode
     (an unlikely internal program bug)
   --this is due to some other unusual error
   Please
   --if the error persists, take the appropriate system action to correct the
     error
*/


#define ERRID_INPUT_OPEN_ERROR						6900
/*
   There was a failure of the internal inputopen() function.
   Perhaps
   --there was some unusual system condition that caused this error
   Please
   --try again, and if the error persists, take the appropriate system
     action to correct the error
 */


#define ERRID_NONEXISTENT_VALUE_REFERENCE				7000
/*
   In your script, you referenced a variable for which there is no value.
   Perhaps
   --this is a data (dat) variable, and there is no input, or no input yet
     (e.g., you are in the script begin section)
   --there has been no 'set' (or other program statement) that would set
     a value yet
   Please
   --review your script for signs of error
   --refer to the Pikt Script Language section of the Reference for
     further explanation
 */

#define ERRID_NONEXISTENT_HISTORY_VALUE_REFERENCE			7001
/*
   In your script, you referenced a history variable for which there is no
   value.
   Perhaps
   --this is the first script run, so there is no history value
   --the referenced variable was absent from the script during the previous
     run
   --there is some other difficulty with the history recall mechanism
   Please
   --rerun the script
   --check the logs and/or .hst file for signs of error
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_NONEXISTENT_PRECEDING_VALUE_REFERENCE			7002
/*
   In your script, you referenced a variable for which there is no value
   for the preceding input line.
   Perhaps
   --you are using a preceding value reference, e.g., @foo, in the begin
     section where there is not input yet
   --there are no rule sections in your script for processing input
   Please
   --review your script for signs of error
   --refer to the Pikt Script Language and Objects, Names, & Datatypes
     sections of the Reference for further explanation
 */

#define ERRID_VAR_OUT_OF_BOUNDS						7003
/*
   An invalid variable type was detected.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_DIVIDE_BY_ZERO						7100
/*
   In your script, there was an attempted divide by zero.
   Please
   --check the indicated number, making sure that the denominator does not
     resolve to zero
 */

#define ERRID_MODULO_ZERO						7101
/*
   In your script, there was an attempted modulo zero operation.
   Please
   --check the indicated number, making sure that the expression after
     the modulo operator does not resolve to zero
 */


#define ERRID_VALUE_NONINTEGRAL						7200
/*
   In your script, the referenced expression resolved to a non-integral
   value.
   Please
   --check the indicated expression, making sure it resolves to an integer
 */

#define ERRID_VALUE_NONINTEGRAL_OR_NEGATIVE				7201
/*
   In your script, the referenced expression resolved to a non-integral
   or negative value.
   Please
   --check the indicated expression, making sure it resolves to a positive
     integer
 */

#define ERRID_VALUE_NONINTEGRAL_OR_OUT_OF_BOUNDS			7202
/*
   In your script, the referenced expression resolved to a non-integral
   or out-of-bounds value.
   Please
   --check the indicated expression, making sure it resolves to a within-
     bounds integer
 */

#define ERRID_VALUE_NONINTEGRAL_OR_INVALID				7203
/*
   In your script, the referenced expression resolved to a non-integral
   or otherwise invalid value.
   Please
   --check the indicated expression, making sure it resolves to a valid
     integer
 */

#define ERRID_VALUE_OUT_OF_BOUNDS					7204
/*
   In your script, the referenced expression resolved to an out-of-bounds
   value.
   Please
   --check the indicated expression, making sure it resolves to a within-
     bounds value
 */

#define ERRID_VALUE_ZERO_OR_NEGATIVE					7205
/*
   In your script, the referenced expression resolved to a zero or negative
   value.
   Please
   --check the indicated expression, making sure it resolves to a positive
     value
 */

#define ERRID_VALUE_NOT_NUMBER						7206
/*
   In your script, the referenced expression was not a valid number.
   Please
   --check the indicated expression, making sure it resolves to a number
 */


#define ERRID_ARRAY_INDEX_NULL						7300
/*
   In your script, the referenced array index expression resolved to the
   the null string.
   Please
   --check the indicated expression, making sure it resolves to a non-null
     string
 */

#define ERRID_ARRAY_INDEX_INVALID					7301
/*
   In your script, the referenced array index expression resolved to an
   invalid value.
   Please
   --check the indicated expression, making sure it resolves to a valid
     value
 */

#define ERRID_ARRAY_INDEX_ZERO_OR_NEGATIVE				7302
/*
   In your script, the referenced array index expression resolved to a zero
   or negative value.
   Please
   --check the indicated expression, making sure it resolves to a positive
     value
 */

#define ERRID_ARRAY_INDEX_NESTING_MAX_EXCEEDED				7303
/*
   You have nested arrays too deeply.
   Perhaps
   --you are doing something like this:  #a[#b[#c[#d[...]]]]
   --you have made some other syntax error
   Please
   --alter your script to reduce the level of array nesting
   --fix the syntax error
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */


#define ERRID_EXPRSTR_NULL						7400
/*
   In your script, a null expression string was detected.
   Please
   --check the expression, making sure it resolves to a non-null string
 */


#define ERRID_STRING_NOT_RESOLVE_TO_NUMBER				7500
/*
   In your script, the indicated expression does not resolve to a number.
   Please
   --check the expression, making sure it resolves to a string
 */

#define ERRID_NUMBER_RESOLVE_TO_STRING					7501
/*
   In your script, the indicated expression is resolving to a string.
   This is a warning only.
   Please
   --check your script, making sure you require a string value, not a number
 */


#define ERRID_POSITION_ARGUMENT_INVALID					7600
/*
   In your script, the #find() (or #index() or #search()) function position
   argument is invalid.
   Please
   --check the function arguments, making sure they are valid
   --refer to the Functions section of the Reference for further explanation
 */
   

#define ERRID_MODE_TYPE_INVALID						7700
/*
   In the #fopen() or #popen() function, the mode type is invalid.
   Please
   --check the function arguments, making sure they are valid
   --refer to the Functions section of the Reference for further explanation
 */


#define ERRID_REGVL_ERROR						7800
/*
   The program encountered a failure of the internal regvl() function.
   Perhaps
   --your array indices are in error
   --there may be some other obvious error in your script
   --this may be an internal program bug
   Please
   --fix the bad array indices
   --fix any obvious errors
   --report the bug to pikt-bug@pikt.org
   --refer to the Pikt Script Language section of the Reference for
     further explanation
 */

#define ERRID_FINDVL_ERROR						7801
/*
   The program encountered a failure of the internal findvl() function.
   Perhaps
   --your array indices are in error
   --there may be some other obvious error in your script
   --this may be an internal program bug
   Please
   --fix the bad array indices
   --fix any obvious errors
   --report the bug to pikt-bug@pikt.org
   --refer to the Pikt Script Language section of the Reference for
     further explanation
 */


#define ERRID_CHAR_MAX_EXCEEDED						7900
/*
   The indicated string function was found to return a string longer than
   the permitted maximum.
   Please
   --check the function call, modifying the arguments as necessary
   --refer to the Pikt Script Language section of the Reference for
     further explanation
 */


#define ERRID_INPUT_MAX_EXCEEDED					8000
/*
   The input string is too long.
   Please
   --check the input string, shortening it as necessary
   --refer to the Pikt Script Language section of the Reference for
     further explanation
 */


#define ERRID_DRIFT_INVALID						8100
/*
   The specified drift value is invalid.
   Please
   --check alerts.cfg, making sure that the indicated drift value is a
     non-negative integer
   --refer to the alerts.cfg section of the Reference for further explanation
 */


#define ERRID_PRIORITY_INVALID						8200
/*
   The specified nice or priority value is invalid.
   Please
   --check alerts.cfg, making sure that the indicated value is an integer
     between -20 and 19
   --refer to the alerts.cfg section of the Reference for further explanation
 */


#define ERRID_TIMINGS_MAX_EXCEEDED					8300
/*
   You have specified too many different alert timings.
   Please
   --reduce the number of different alert timings
   --refer to the alerts.cfg section of the Reference for further explanation
 */

#define ERRID_TIMING_VAL_INVALID					8301
/*
   The specified timing value is invalid.
   Please
   --fix the invalid timing value
   --refer to the alerts.cfg section of the Reference, also the cron man
     pages, for further explanation
 */

#define ERRID_TIMING_PERIODS_NOT_ASCENDING				8302
/*
   The specified timing periods were not increasing in value.
   Please
   --fix the invalid timing, making them ascend in value
   --refer to the alerts.cfg section of the Reference, also the cron man
     pages, for further explanation
 */


#define ERRID_HISTORY_LOG_FILE_NAME_MISMATCH				8400
/*
   The filename in your 'input log' statement doesn't match the filename
   for this alarm script in the .hst file.
   Perhaps
   --you have changed the name of the log file, or simply misspelled it
   Please
   --fix the spelling, if necessary
   --simply ignore the warning if this is a legitimate log file name change
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_KEY_INDEX_OUT_OF_SEQUENCE				8401
/*
   The program has detected a change in the key order.
   Please
   --simply ignore the warning if the change is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_NEW_KEY_ADDED					8402
/*
   The program has detected new additions to the 'keys' statement (i.e.,
   one or more keys not found in the .hst file).
   Please
   --simply ignore the warning if the addition of these keys is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_KEY_INDEX_UNKNOWN				8403
/*
   The program has detected a key in the .hst file that appears no longer
   to be in use.
   Please
   --simply ignore the warning if the addition of these keys is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_VAR_INDEX_CHANGED				8404
/*
   The program has detected a change in the history variable, or attempted
   use of a reserved variable name, or a variable name no longer in use by
   the script.
   Please
   --simply ignore the warning if the anomalies are legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_VAR_INDEX_UNKNOWN				8405
/*
   The program has detected a variable name in the .hst file that is no
   longer referenced for its history value.
   Please
   --simply ignore the warning if the anomaly is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_VAR_INDEX_DUPLICATED				8406
/*
   The program has detected a repeat mention of this variable name in the
   .hst file.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_VAR_FLDNUM_MISMATCH				8407
/*
   This error has been deprecated.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */

#define ERRID_HISTORY_FILE_VAR_ARYDIM_MISMATCH				8408
/*
   For the indicated variable, its array dimension has changed between the
   .hst file and the current alarm script.
   Please
   --simply ignore the warning if the anomaly is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_VAR_DATTYP_MISMATCH				8409
/*
   For the indicated variable, its dat type has changed between the .hst
   file and the current alarm script.
   Please
   --the variable was a number type before and is now a string, or vice versa
   --simply ignore the warning if the anomaly is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_OLD_VAL_INDEX_UNKNOWN			8410
/*
   The indicated variable index was not found in the old (.hst file)
   history variables list.
   Please
   --simply ignore the warning if the anomaly is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_NEW_VAL_INDEX_UNKNOWN			8411
/*
   The indicated variable index was not found in the new (current script)
   history variables list.
   Please
   --simply ignore the warning if the anomaly is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */

#define ERRID_HISTORY_FILE_ALARM_RETIRED				8412
/*
   The indicated alarm script was found in the .hst file but is absent from
   the new .alt file.
   Please
   --simply ignore the warning if the anomaly is legitimate
     (and note that the history value recall mechanism was temporarily
     switched off during that program run)
   --refer to the History Logging section of the Reference for further
     explanation
 */


#define ERRID_ISEXECTYPE_INDETERMINATE					8500
/*
   The program wasn't able to determine 'exec' type (whether 'exec' or 'exec
   wait').
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_FILE_SIZE_MISMATCH					8600
/*
   After unencryption, the target file size doesn't match the source file
   size.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_MEMBERS_TOO_MANY						8700
/*
   There are too many members in the indicated group (has exceeded the
   length of an internal program buffer).
   Perhaps
   --this is a very sizable group; consider reducing the number of group
     members
   Please
   --consider increasing the MAXLINE #define in src/lib/common.h, or
     increase the size of the members[] buffer in the grmem() function
     in src/piktd/expr.c, then recompile and reinstall the affected PIKT
     binaries
 */


#define ERRID_VAR_SET_ATTEMPTED						8800
/*
   You have attempted to set a new value for a dat variable with a fixed
   value (from the current input line).
   Please
   --remove the 'set' statement, or use a different variable name
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */

#define ERRID_VAR_UNSET_ATTEMPTED					8801
/*
   You have attempted to unset the value for a dat variable with a fixed
   value (from the current input line).
   Please
   --remove the 'unset' statement, or use a different variable name
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */


#define ERRID_COMMAND_STRING_LEN_MAX_EXCEEDED				8900
/*
   The indicated command string is too long.
   Please
   --shorten the command string
 */

#define ERRID_COMMAND_STRING_MISSING					8901
/*
   The indicated command string resolves to the null string.
   Please
   --specify a non-null command string
 */

#define ERRID_COMMAND_STRING_INVALID					8902
/*
   The program has detected an invalid command string when attempting to
   execute an alert on the slave.
   Perhaps
   --this may be an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_CORE_FILE_FOUND						9000
/*
   When killing the slave system piktd, a core file was created (and removed).
   Please
   --just ignore this warning
 */

#define ERRID_CORE_FILE_REMOVED						9001
/*
   When killing the slave system piktd, a core file was (created and) removed.
   Please
   --just ignore this warning
 */


#define ERRID_PIKTDCONF_ENTRY_MISSING					9100
/*
   When attempting to determine an alert status, the corresponding piktd.conf
   entry was not found.
   Please
   --just ignore this warning
 */


#define ERRID_PIKTDCONF_ARG_LEN_MAX_EXCEEDED				9200
/*
   The proposed piktd.conf line was too long (exceeded the length of an
   internal program buffer).
   Perhaps
   --you have listed too many mail recipients
   Please
   --shorten the piktd.conf line by, for example, reducing the number of
     mail recipients or mailing to a list
   --consider increasing the MAXLINE #define in src/lib/common.h, then
     recompile and reinstall the affected PIKT binaries
 */

#define ERRID_PIKTDCONF_LINE_LEN_MAX_EXCEEDED				9201
/*
   The indicated piktd.conf line was too long (exceeded the length of an
   internal program buffer).
   Please
   --shorten the piktd.conf line by, for example, reducing the number of
     mail recipients
   --consider increasing the MAXLINE #define in src/lib/common.h, or
     increase the size of the line[] buffer in the readconf() function
     in src/piktd/piktd.c, then recompile and reinstall the affected PIKT
     binaries
 */

#define ERRID_PIKTDCONF_LINE_INVALID					9202
/*
   The indicated piktd.conf line is invalid.  The required fields are:
   minutes, hours, days_of_month, months, days_of_week, drift, command_string
   Perhaps
   --it is missing some required fields
   --it has too many fields
   --the fields are of the wrong type
   Please
   --refer to the alerts.cfg section of the Reference for further
     explanation
 */

#define ERRID_PIKTDCONF_NO_ALERTS_ENABLED				9203
/*
   In piktd.conf, no enabled alerts were found.
   Perhaps
   --you have disabled all alerts, using 'piktc -d +A ...' on the
     piktmaster
   Please
   --re-enable one or more alerts, using 'piktc -e +A ...' on the
     piktmaster
   --refer to the piktc section of the Reference for further explanation
 */


#define ERRID_PIKTD_RESTART_ERROR					9300
/*
   piktc_svc was unable to (re)start a new piktd process.
   Perhaps
   --the old piktd process (if any) was not killed, so blocked formation of
     a new, replacement piktd process
   --an orphaned piktd.lock file blocked launch of a new piktd process
   --there was an error in the piktd.conf file (or it was nonexistent)
   Please
   --manually kill the old, blocking piktd process (if any)
   --manually remove any blocking piktd.lock file
   --re-enable all alerts, thereby fixing any piktd.conf problems
   --refer to the piktc and piktd sections of the Reference for further
     explanation
 */


#define ERRID_NO_INPUT_SOURCE						9400
/*
   There is no effective input source.
   Perhaps
   --the input source string is the null string
   --the input source generates no input
   Please
   --review the input source, making sure that it generates actual content
   --refer to the Pikt Script Language section of the Reference for further
     explanation
 */


#define ERRID_MSG_CMD_NULL						9500
/*
   There is no destination process to send alert messages to.
   Perhaps
   --you have omitted a required mailcmd or lpcmd from the alert
     specification
   Please
   --review the alert specification in alerts.cfg
   --refer to the alerts.cfg section of the Reference for further explanation
 */


#define ERRID_ATTEMPTED_DOUBLECHECK_ON_NON_MASTER			9600
/*
   You are attempting a 'pikt -C' operation on a non-master PIKT system.
   Please
   --only perform doublechecks on the piktmaster only ('piktc -C' calls
     'pikt -C' on the master system implicitly)
 */


#define ERRID_ALARM_INACTIVE						9700
/*
   The indicated alarm script is inactive and will therefore not run.
   Perhaps
   --you have 'status inactive', as opposed to 'status active', in your
     alarm script
   Please
   --change the 'status' setting to 'active', unless you truly wish the
     alarm script not to run
   --refer to the Init Section section of the Reference for further
     explanation
 */


#define ERRID_STATEMENT_INACTIVE					9800
/*
   In pikt, the indicated statement will not be processed.
   Perhaps
   --there is an error in the statement string
   Please
   --review and fix any errors
 */


#define ERRID_MIN_ALERT_INTERVAL_EXCEEDED				9900
/*
   The timing drift value is too large, and there is a possibility of
   script schedule overlap.
   Perhaps
   --you have, for example, set an alert to run hourly with a drift of
     more than 30 minutes
   Please
   --reduce the drift value
   --refer to the alerts.cfg section of the Reference for further
     explanation
 */


#define ERRID_REGCOMP_ERROR						10000
/*
   A call to the system regcomp() function failed.
   Perhaps
   --the indicated regular expression is too long
   --the indicated regular expression has a syntax error, or is unusually
     complex
   Please
   --shorten the regular expression
   --fix any syntax error, or simplify the regexp
 */


#define ERRID_DATA_MISMATCH						10100
/*
   The scanned input line failed to match the specified dat (data) fields.
   Perhaps
   --this is an anomalous line
   --you have mis-specified the dat (data) fields
   Please
   --simply disregard the anomalous line, if it is an exception
   --fix the dat (data) specifications
   --refer to the Init Section section of the Reference for further
     explanation
 */


#define ERRID_STATEMENT_RETURN_INVALID					10200
/*
   The program has encountered an invalid dostatement() return value.
   Perhaps
   --this is most likely an internal program bug
   Please
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_DIE_STATEMENT						10300
/*
   The program has died with the given explanation.
   Perhaps
   --this is intentional
   Please
   --just note the explanation, or fix any problem as needed
 */


#define ERRID_LOG_TO_DEV_NULL_STATEMENT					10400
/*
   pikt wrote the indicated log string to /dev/null, in effect not logging
   it at all.
   Please
   --just note this, or fix any problem as needed
 */


#define ERRID_SYSLOG_ENTRY						10500
/*
   pikt is logging the indicated log string to the system syslog facility.
   Please
   --just note this, or fix any problem as needed
 */


#define ERRID_PIKTLOG_ENTRY						10600
/*
   pikt is logging the indicated log string to the standard alert log.
   Please
   --just note this, or fix any problem as needed
 */


#define ERRID_SYSLOG_FACILITY_INVALID					10700
/*
   You have specified an invalid syslog level in PIKT.conf.
   Please
   --specify one of the valid syslog levels, from 0 to 7
 */


#define ERRID_PS_READ_ERROR						10800
/*
   The program was unable to read or properly parse the ps output.
   Perhaps
   --your PSPARSE value is improperly set for this system
   --this is an internal program bug (unlikely)
   Please
   --review the PSPARSE setting in the configure files, and if needed
     change, then recompile and reinstall all affected PIKT binaries
   --report the bug to pikt-bug@pikt.org
 */


#define ERRID_CONFLICTING_OPTIONS					10900
/*
   You have specified piktc command line options that are in conflict and/or
   are inconsistent with one another.
   Please
   --refer to the piktc section of the Reference for further explanation
 */


#define ERRID_INDENT_WITH_OPEN_INDENT					11000
/*
   You have specified an #indent with a still open earlier #indent.
   Please
   --remove this new, redundant #indent directive
   --close the earlier #indent directive
 */

#define ERRID_UNINDENT_WITHOUT_OPEN_INDENT				11001
/*
   You have specified an #unindent with no open earlier #indent.
   Please
   --remove this #unindent directive
   --check any earlier #indent directive
 */
