/*
   timing.c -- PIKT piktd timing routines

   $Header: /var/cvs/PIKT/pikt/src/piktd/timing.c,v 1.17 2005/01/04 13:49:04 berto Exp $

   This file is part of PIKT ("Problem Informant/Killer Tool").
   Copyright (C) 1998,1999,2000,2001,2002,2003,2004,2005 by Robert Osterlund.

   PIKT is a trademark of the University of Chicago.  All Rights Reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   PIKT is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
   USA.

   Send problem reports, bouquets and brickbats to:  pikt-bugs@pikt.org
*/

#include "../lib/common.h"
#include "piktd.h"

char *tcp;
float tp;
unsigned long cb;
int clo, chi, cmin, cmax;
int mop;
int map;
int ttp;
int etp;
int ptp;
int mai;

/* given a timing parameter, e.g., "0,1,4,5,6,10-20/2", set up various
   other parameters (e.g., the allowed range for this parameter, 1..12
   in the case of months), before invoking timingparse()
 */
void
parsetiming (char *tim, float *timeprob, unsigned long *timeval,
             int loval, int hival, int minval, int maxval,
             int total_time_periods,
             int mins_one_period, int mins_all_periods)
{

	clo = loval;
	chi = hival;
	cmin = minval;
	cmax = maxval;
	ttp = total_time_periods;
	mop = mins_one_period;
	map = mins_all_periods;
	etp = NONE;
	ptp = NONE;
	tp = 0.00;
	cb = 0UL;
	tcp = tim;
	timingparse();
	*timeprob = tp;
	*timeval = cb;
}

/* randomizetimer(n) (where n is a postive integer) returns a random
   unsigned integer from 0 to n;
   we might use random() instead of rand() here eventually, but rand()
   should be "good enough" for PIKT purposes
 */
unsigned int
randomizetimer (unsigned int n)
{
	double r;

	r = (double)rand()/((double)(RAND_MAX)+1.0);	/* random number, 0.0 <= r < 1.0 */
	return (int)(r*(n+1));
}

/* set current time bits
 */
void
settimebits (struct tm *tm, unsigned long *himin, unsigned long *lomin,
                            unsigned long *hr,    unsigned long *dom,
                            unsigned long *mon,   unsigned long *dow)
{

	if (tm->tm_min < 32) {
		*himin = 0UL;
		*lomin = (1UL << tm->tm_min);
	} else {
		*himin = (1UL << (tm->tm_min % 32));
		*lomin = 0UL;
	}
	*hr    = (1UL << tm->tm_hour);
	*dom   = (1UL << tm->tm_mday);
	*mon   = (1UL << (tm->tm_mon + 1));
	*dow   = (1UL << tm->tm_wday);
	return;
}

/* check for a match between the current time and the given alert's timing
   parameters; return TRUE if match, FALSE if not
 */
int
timematch (alt *altp, unsigned long himin, unsigned long lomin,
                      unsigned long hr,    unsigned long dom,
                      unsigned long mon,   unsigned long dow)
{

	if (    (    (altp->minprob && (altp->minprob >= (float)rand()/(float)RAND_MAX))
	          || (altp->himin & himin)
	          || (altp->lomin & lomin)
	        )
	     && (    (altp->hrprob  && (altp->hrprob  >= (float)rand()/(float)RAND_MAX))
	          || (altp->hr    & hr)
	        )
	     && (    (altp->domprob && (altp->domprob >= (float)rand()/(float)RAND_MAX))
	          || (altp->dom   & dom)
	        )
	     && (    (altp->monprob && (altp->monprob >= (float)rand()/(float)RAND_MAX))
	          || (altp->mon   & mon)
	        )
	     && (    (altp->dowprob && (altp->dowprob >= (float)rand()/(float)RAND_MAX))
	          || (altp->dow   & dow)
	        )
	   ) {
		return TRUE;
	} else {
		return FALSE;
	}
}
